@@ -1,6 +1,6 @@
 bylevs <- function(x) {
   if (is.factor(x))
-    res <- levels(x)
+    res <- levels(factor(x))
   else
     res <- unique(x)
   res
