@@ -4,10 +4,8 @@ chkcolor <- function(x, single = TRUE, name = NULL) {
   ##
   if (single) {
     if (length(x) != 1)
-      stop(paste("Argument '", name,
-                 "' must have a single value.", sep = ""))
+      stop("Argument '", name, "' must have a single value.")
   }
   else if (!(is.character(x) || is.numeric(x)))
-    stop(paste("Argument '", name,
-               "' must be a character or numeric vector.", sep = ""))
+    stop("Argument '", name, "' must be a character or numeric vector.")
 }
